@@ -18,6 +18,11 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
 
+'''
+	Client library for GraphIT.
+	Contains also mini-framework for helpers.
+'''
+
 import sys
 
 from optparse import OptionParser
@@ -27,6 +32,16 @@ from socket import gethostname
 from restkit import RestClient, httpc
 
 class GraphItAgent:
+	''' 
+		This class allow to connect on GraphIT server and submit
+		some monitoring data.
+		
+		Exemple:
+		
+		>>> agent = GraphItAgent('http://graphit.lan/')
+		>>> agent.add_value('load', '1m', 0.42)
+		>>> agent.add_value('load', '5m', 0.2)
+	 '''
 	
 	def __init__(self, base_url, login=None, passwd=None):
 		
@@ -46,14 +61,15 @@ class GraphItAgent:
 		
 		self._client.post(
 			self.base_url,
-			path = '%s/%s' % (set, feed),
+			path = '%s/%s' % (set.replace('/', '%2F'), feed.replace('/', '%2F')),
 			body = {'value': value, 'unit': unit},
 			headers = {'Content-type': ('application/x-www-form-urlenco'
 										'ded; charset=utf-8')},
 		)
 
+
 class GraphITWatcher(GraphItAgent):
-	''' GraphITWatcher is program used to watch a specific ressource
+	''' GraphIT Watcher is program used to watch a specific ressource
 	and submit it values to the GraphIT daemon. '''
 
 	__name__ = None
@@ -98,7 +114,7 @@ class GraphITWatcher(GraphItAgent):
 			sys.exit(0)
 		
 		# Validating:
-		if len(args) != 1:
+		if len(args) < 1:
 			op.error(('Watcher needs URL of GraphIT daemon to'
 						' which to send the data'))
 		
@@ -114,7 +130,7 @@ class GraphITWatcher(GraphItAgent):
 		
 		url = 'http://%s%s/%s' % (self._url.hostname, port, self._url.query)
 		
-		self.check_options(op)
+		self.check_options(op, args)
 		
 		# Super
 		GraphItAgent.__init__(
@@ -127,9 +143,12 @@ class GraphITWatcher(GraphItAgent):
 		self.run()
 
 	def init_options(self, op):
+		''' Method to overload for adding cli options to Watcher. '''
 		pass
 
-	def check_options(self, op):
+	def check_options(self, op, args):
+		''' Method to overload for checking new added cli options
+		to watcher. '''
 		pass
 
 	def get_set(self):
